//
// SimpleEnum.java
//
// The contents of this file are subject to the SNIA Public License Version 1.0
// (the "License"); you may not use this file except in compliance with the
// License. You may obtain a copy of the License at
//
//	http://www.snia.org/resources/openSource.html
//
// Software distributed under the License is distributed on an "AS IS" basis,
// WITHOUT WARRANTY OF ANY KIND, either express or implied. See the 
// License for the specific language governing rights and limitations
// under the License.
//
// The Original Code is SimpleEnum.java
// 
// The Initial Developer of the Original Code is David Simons.
//
// Contributor(s):
//
//
// $Id: SimpleEnum.java,v 1.1 2003/07/17 18:32:55 kumpf Exp $
//
//
package org.snia.wbemcmd.utils;

import java.io.Serializable;
import java.util.Enumeration;
import java.util.Vector;



public class SimpleEnum implements Enumeration,Serializable {
    Vector vector=new Vector();
    int offset=0;
	
    public void addElement(Object obj) {
	vector.addElement(obj);
    }
    public boolean contains(Object obj) {
	return(vector.contains(obj));
    }
    public boolean hasMoreElements() {return(offset<vector.size());}
    public Object nextElement() {return(vector.elementAt(offset++));}
    public Vector getVector() {
	return vector;
    }
}
